#!/usr/bin/env python
# encoding=utf-8

from kakashi.arg_parse import *
from kakashi.logger import *
from kakashi.kakashi import Kakashi


def main():
    Kakashi()


if __name__ == '__main__':
    main()
